@@ -6,29 +6,31 @@ from django.template import Context
 from django.template.loader import get_template
 from django import template
 from django.conf import settings
+from django.utils.html import format_html_join
 
 BOOTSTRAP_BASE_URL = getattr(settings, 'BOOTSTRAP_BASE_URL',
-    'http://twitter.github.com/bootstrap/assets/'
+                             'http://twitter.github.com/bootstrap/assets/'
 )
 
 BOOTSTRAP_JS_BASE_URL = getattr(settings, 'BOOTSTRAP_JS_BASE_URL',
-    BOOTSTRAP_BASE_URL + 'js/'
+                                BOOTSTRAP_BASE_URL + 'js/'
 )
 
 BOOTSTRAP_JS_URL = getattr(settings, 'BOOTSTRAP_JS_URL',
-    None
+                           None
 )
 
 BOOTSTRAP_CSS_BASE_URL = getattr(settings, 'BOOTSTRAP_CSS_BASE_URL',
-    BOOTSTRAP_BASE_URL + 'css/'
+                                 BOOTSTRAP_BASE_URL + 'css/'
 )
 
 BOOTSTRAP_CSS_URL = getattr(settings, 'BOOTSTRAP_CSS_URL',
-    BOOTSTRAP_CSS_BASE_URL + 'bootstrap.css'
+                            BOOTSTRAP_CSS_BASE_URL + 'bootstrap.css'
 )
 
 register = template.Library()
 
+
 @register.simple_tag
 def bootstrap_stylesheet_url():
     """
@@ -36,6 +38,7 @@ def bootstrap_stylesheet_url():
     """
     return BOOTSTRAP_CSS_URL
 
+
 @register.simple_tag
 def bootstrap_stylesheet_tag():
     """
@@ -43,6 +46,7 @@ def bootstrap_stylesheet_tag():
     """
     return u'<link rel="stylesheet" href="%s">' % bootstrap_stylesheet_url()
 
+
 @register.simple_tag
 def bootstrap_javascript_url(name=None):
     """
@@ -55,6 +59,7 @@ def bootstrap_javascript_url(name=None):
     else:
         return BOOTSTRAP_JS_BASE_URL + 'bootstrap.min.js'
 
+
 @register.simple_tag
 def bootstrap_javascript_tag(name=None):
     """
@@ -65,6 +70,7 @@ def bootstrap_javascript_tag(name=None):
         return u'<script src="%s"></script>' % url
     return u''
 
+
 @register.filter
 def as_bootstrap(form_or_field, layout='vertical,false'):
     """
@@ -98,6 +104,7 @@ def as_bootstrap(form_or_field, layout='vertical,false'):
         # Display the default
         return settings.TEMPLATE_STRING_IF_INVALID
 
+
 @register.filter
 def is_disabled(field):
     """
@@ -111,6 +118,7 @@ def is_disabled(field):
         return True
     return False
 
+
 @register.filter
 def is_enabled(field):
     """
@@ -118,6 +126,7 @@ def is_enabled(field):
     """
     return not is_disabled(field)
 
+
 @register.filter
 def bootstrap_input_type(field):
     """
@@ -140,6 +149,7 @@ def bootstrap_input_type(field):
         return u'radioset'
     return u'default'
 
+
 @register.simple_tag
 def active_url(request, url, output=u'active'):
     # Tag that outputs text if the given url is active for the request
@@ -147,6 +157,7 @@ def active_url(request, url, output=u'active'):
         return output
     return ''
 
+
 @register.filter
 def pagination(page, pages_to_show=11):
     """
@@ -201,12 +212,25 @@ def pagination(page, pages_to_show=11):
         })
     )
 
+
 @register.filter
-def split(str, splitter):
+def split(text, splitter):
     """
     Split a string
     """
-    return str.split(splitter)
+    return text.split(splitter)
+
+
+@register.filter
+def html_attrs(attrs):
+    """
+    display the attributes given as html attributes :
+    >>> import collections
+    >>> html_attrs(collections.OrderedDict([('href',"http://theurl.com/img.png"), ('alt','hi "guy')]))
+    u'href="http://theurl.com/img.png" alt="hi &quot;guy" '
+    """
+    return format_html_join(u' ', '{0}="{1}"', (item for item in attrs.items())) + " "
+
 
 @register.simple_tag(takes_context=True)
 def bootstrap_messages(context, *args, **kwargs):
@@ -215,6 +239,7 @@ def bootstrap_messages(context, *args, **kwargs):
     """
     return get_template("bootstrap_toolkit/messages.html").render(context)
 
+
 @register.inclusion_tag("bootstrap_toolkit/form.html")
 def bootstrap_form(form, **kwargs):
     """
@@ -224,6 +249,7 @@ def bootstrap_form(form, **kwargs):
     context['form'] = form
     return context
 
+
 @register.inclusion_tag("bootstrap_toolkit/field.html")
 def bootstrap_field(field, **kwargs):
     """
@@ -232,3 +258,5 @@ def bootstrap_field(field, **kwargs):
     context = kwargs.copy()
     context['field'] = field
     return context
+
+
